/*
 * speechd_defines.h - macros for Speech Dispatcher
 *
 * Copyright (C) 2015 Brailcom, o.p.s.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef SPEECHD_DEFINES_H
#define SPEECHD_DEFINES_H

#define SPD_ALLCLIENTS "ALL"
#define SPD_SELF "SELF"
#define SPD_VOLUME "VOLUME"
#define SPD_PITCH "PITCH"
#define SPD_PITCH_RANGE "PITCH_RANGE"
#define SPD_RATE "RATE"
#define SPD_LANGUAGE "LANGUAGE"
#define SPD_OUTPUT_MODULE "OUTPUT_MODULE"
#define SPD_SYNTHESIS_VOICE "SYNTHESIS_VOICE"

#endif /* not ifndef SPEECHD_DEFINES_H */
